@@ -1,8 +1,6 @@
 from dagster import (
     In,
-    InputDefinition,
     Out,
-    OutputDefinition,
     config_from_files,
     file_relative_path,
     fs_io_manager,
@@ -10,6 +8,7 @@ from dagster import (
     in_process_executor,
     repository,
 )
+from dagster._legacy import InputDefinition, OutputDefinition
 
 from ..data_frame import DataFrame
 from .pandas_hello_world.ops import always_fails_op, papermill_pandas_hello_world, sum_op, sum_sq_op
